/*   $Source: bitbucket.org:berkeleylab/gasnet.git/pami-conduit/gasnet_core_help.h $
 * Description: GASNet PAMI conduit core Header Helpers (Internal code, not for client use)
 * Copyright 2012, Lawrence Berkeley National Laboratory
 * Terms of use are as specified in license.txt
 */

#ifndef _IN_GASNET_H
  #error This file is not meant to be included directly- clients should include gasnet.h
#endif

#ifndef _GASNET_CORE_HELP_H
#define _GASNET_CORE_HELP_H

#include <gasnet_help.h>

#endif
